.. _api:

API
===

The Translate Toolkit provides several modules for programmers to build
their own tools.

Module overview
----------------

The following will give you an idea about what each module is capable of.

convert
^^^^^^^
.. automodule:: translate.convert

filters
^^^^^^^
.. automodule:: translate.filters

lang
^^^^
.. automodule:: translate.lang

misc
^^^^
.. automodule:: translate.misc

search
^^^^^^
.. automodule:: translate.search

services
^^^^^^^^
.. automodule:: translate.services

storage
^^^^^^^
.. automodule:: translate.storage

tools
^^^^^
.. automodule:: translate.tools


Module list
------------

All the modules included in the Translated Toolkit are listed here.

.. toctree::
   :maxdepth: 3

   convert
   filters
   lang
   misc
   search
   services
   storage
   tools
